import { Injectable } from '@nestjs/common';
import {
  HealthCheckError,
  HealthIndicator,
  HealthIndicatorResult,
} from '@nestjs/terminus';
import { ConfigurationRepository } from '../../../configuration/adapters/secondaries/configuration.repository';

@Injectable()
export class PrismaHealthIndicatorUseCase extends HealthIndicator {
  constructor(private readonly _repository: ConfigurationRepository) {
    super();
  }

  async isHealthy(key: string): Promise<HealthIndicatorResult> {
    try {
      await this._repository.healthCheck();
      return this.getStatus(key, true);
    } catch (e) {
      throw new HealthCheckError('Prisma', {
        prisma: e.message,
      });
    }
  }
}
